@@ -26,12 +26,14 @@
 
 #include "macros.h"
 
+#undef signals
 #include <nm-version.h>
 #if NM_CHECK_VERSION(1, 0, 0)
 #include <libnm/NetworkManager.h>
 #else
 #include <NetworkManager.h>
 #endif
+#define signals Q_SIGNALS
 
 #include "activeconnection.h"
 #include "adsldevice.h"
@@ -110,7 +112,7 @@ NetworkManager::NetworkManagerPrivate::NetworkManagerPrivate()
     connect(&iface, &OrgFreedesktopNetworkManagerInterface::PropertiesChanged,
             this, &NetworkManagerPrivate::propertiesChanged);
 #endif
-   
+
     connect(&watcher, &QDBusServiceWatcher::serviceRegistered,
             this, &NetworkManagerPrivate::daemonRegistered);
     connect(&watcher, &QDBusServiceWatcher::serviceUnregistered,
@@ -680,8 +682,8 @@ void NetworkManager::NetworkManagerPrivate::onDeviceAdded(const QDBusObjectPath
     // qCDebug(NMQT);
     if (!networkInterfaceMap.contains(objpath.path())) {
         networkInterfaceMap.insert(objpath.path(), Device::Ptr());
+        Q_EMIT deviceAdded(objpath.path());
     }
-    Q_EMIT deviceAdded(objpath.path());
 }
 
 void NetworkManager::NetworkManagerPrivate::onDeviceRemoved(const QDBusObjectPath &objpath)
@@ -893,13 +895,15 @@ void NetworkManager::NetworkManagerPrivate::daemonUnregistered()
 NetworkManager::ActiveConnection::List NetworkManager::NetworkManagerPrivate::activeConnections()
 {
     NetworkManager::ActiveConnection::List list;
-    QMap<QString, ActiveConnection::Ptr>::const_iterator it = m_activeConnections.constBegin();
-    while (it != m_activeConnections.constEnd()) {
-        NetworkManager::ActiveConnection::Ptr activeConnection = findRegisteredActiveConnection(it.key());
+
+    // We do not use const_iterator here because
+    // findRegisteredActiveConnection() changes m_activeConnections.
+    foreach (const QString &key, m_activeConnections.keys()) {
+        NetworkManager::ActiveConnection::Ptr activeConnection = findRegisteredActiveConnection(key);
+
         if (activeConnection) {
             list << activeConnection;
         }
-        ++it;
     }
     return list;
 }
